#!/usr/bin/env python

# Authors:
#   David Green <david4dev@gmail.com>
#
# QR Code Creator: Application to create QR Codes (2D barcodes).
# Copyright (C) 2011 David Green <david4dev@gmail.com>
#
# This file is part of `QR Code Creator`.
#
# `QR Code Creator` is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# `QR Code Creator` is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along
# with `QR Code Creator`.  If not, see <http://www.gnu.org/licenses/>.

import sys
import os
import gtk
import time
import hashlib
import subprocess
import shutil
import gettext
_ = gettext.gettext

class QRCodeCreator(gtk.Window):
    def __init__(self):
        super(QRCodeCreator, self).__init__()
        self.directory = os.path.join('/tmp', "qr-code-creator-%f" % time.time())
        os.makedirs(self.directory)
        self.set_title(_("QR Code Creator"))
        self.widget = {}
        self.add_widgets()
        self.widget['text_entry'].set_text(_("QR Code Creator"))
        self.widget['size_entry'].set_text('3')
        self.make_qr()
        self.set_icon_from_file(self.current_image)
        self.connect_events()
        self.show()

    def add_widget(self, name, widget, parent='container'):
        widget.show()
        self.widget[parent].add(widget)
        self.widget[name] = widget

    def add_widgets(self):
        self.widget['container'] = gtk.VBox()
        self.widget['container'].show()
        self.add(self.widget['container'])

        self.add_widget('text', gtk.HBox())
        self.add_widget('text_label', gtk.Label(_("Text: ")), 'text')
        self.add_widget('text_entry', gtk.Entry(), 'text')

        self.add_widget('size', gtk.HBox())
        self.add_widget('size_label', gtk.Label(_("Pixel Size: ")), 'size')
        self.add_widget('size_entry', gtk.Entry(), 'size')

        self.add_widget('button', gtk.Button())
        self.add_widget('image', gtk.Image(), 'button')

    def connect_event(self, widget, event, callback):
        self.widget[widget].connect(event, callback)

    def connect_events(self):
        self.connect("delete_event", self.delete_event)
        self.connect("destroy", self.destroy)
        self.connect_event('text_entry', 'changed', self.make_qr)
        self.connect_event('size_entry', 'changed', self.make_qr)
        self.connect_event('button', 'clicked', self.open_image)

    def make_qr(self, *a):
        text = 'NULL'
        try:
            text = self.widget['text_entry'].get_text()
            if text == '':
                text = 'NULL'
        except:
            pass
        size = 3
        try:
            size = int(self.widget['size_entry'].get_text())
        except:
            pass
        self.current_image = os.path.join(self.directory, "%s.png" % hashlib.sha256(text).hexdigest())
        subprocess.Popen(['qrencode', '-o', self.current_image, '-s', str(size), text]).wait()
        self.widget['image'].set_from_file(self.current_image)

    def open_image(self, *a):
        subprocess.Popen(['xdg-open', self.current_image])

    def destroy(self, widget, data=None):
        shutil.rmtree(self.directory)
        gtk.main_quit()

    def delete_event(self, widget, event, data=None):
        return False

    def main(self):
        gtk.main()

QRCodeCreator().main()



